import commonjs from '@rollup/plugin-commonjs';
import resolve from '@rollup/plugin-node-resolve';
import replace from '@rollup/plugin-replace';
import peerDepsExternal from 'rollup-plugin-peer-deps-external';
import typescript from '@rollup/plugin-typescript';
import sass from 'sass';
import scss from 'rollup-plugin-scss';
import image from '@rollup/plugin-image';
import json from '@rollup/plugin-json';
import terser from '@rollup/plugin-terser';

export default {
  input: 'resources/ts/birds/main.tsx',
  output: [
    {
      file: 'assets/birds.js',
      name: 'app',
      sourcemap: 'inline',
      format: 'es',
      inlineDynamicImports: true,
    },
  ],
  onwarn(warning, warn) {
    if (warning.code === 'MODULE_LEVEL_DIRECTIVE') {
      return;
    }
    warn(warning);
  },
  plugins: [
    peerDepsExternal(),
    resolve({
      browser: true,
      dedupe: ['react', 'react-dom'],
    }),
    replace({
      preventAssignment: true,
      'process.env.NODE_ENV': JSON.stringify('production'),
    }),
    commonjs(),
    typescript({
      tsconfig: 'tsconfig.json',
      sourceMap: true,
      inlineSources: true,
    }),
    image(),
    scss({
      fileName: 'style.css',
      outputStyle: process.env.NODE_ENV === 'production' ? 'compressed' : 'expanded',
      runtime: sass,
      failOnError: true,
    }),
    json(),
    terser(),
  ],
};
